/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.demo.chess;

import static org.testng.Assert.*;
import org.testng.annotations.Test;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class BoardModelTest {
    
    public BoardModelTest() {
    }


    @Test public void e2e4() {
        Board b = BoardModel.createBoard();
        Square e2 = BoardModel.findSquare(b, 'E', 2);
        assertNotNull(e2);
        BoardModel.selected(b, e2);
        assertEquals(BoardModel.findSelectedSquare(b), e2, "E2 is selected");
        
        Square e4 = BoardModel.findSquare(b, 'E', 4);
        assertNotNull(e4);
        
        BoardModel.selected(b, e4);
        
        assertNull(e2.getPiece(), "No pawn at e2");
        assertEquals(e4.getPiece(), BoardModel.PieceType.PAWN, "Pawn moved successfully");
        assertNull(BoardModel.findSelectedSquare(b), "No square selected");
        
    }
    
    @Test public void cantSelectEmptySquare() {
        Board b = BoardModel.createBoard();
        Square e3 = BoardModel.findSquare(b, 'E', 3);
        assertNotNull(e3);
        BoardModel.selected(b, e3);
        assertNull(BoardModel.findSelectedSquare(b), "No square is selected");
    }
    
}
